@@ -86,7 +86,7 @@
 #define KRUNNER_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KRUNNER_NO_DEPRECATED
-#  define KRUNNER_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55e00
+#  define KRUNNER_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55f00
 #endif
 #ifdef KRUNNER_NO_DEPRECATED_WARNINGS
 #  define KRUNNER_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KRUNNER_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KRUNNER_DEPRECATED_WARNINGS_SINCE KRUNNER_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KRUNNER_DEPRECATED_WARNINGS_SINCE 0x55e00
+#    define KRUNNER_DEPRECATED_WARNINGS_SINCE 0x55f00
 #  endif
 #endif
 
@@ -246,7 +246,7 @@
 #define KRUNNER_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KRUNNER_NO_DEPRECATED
-#  define KRUNNER_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55e00
+#  define KRUNNER_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55f00
 #endif
 #ifdef KRUNNER_NO_DEPRECATED_WARNINGS
 #  define KRUNNER_DEPRECATED_WARNINGS_SINCE 0
@@ -256,7 +256,7 @@
 #  ifdef KRUNNER_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KRUNNER_DEPRECATED_WARNINGS_SINCE KRUNNER_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KRUNNER_DEPRECATED_WARNINGS_SINCE 0x55e00
+#    define KRUNNER_DEPRECATED_WARNINGS_SINCE 0x55f00
 #  endif
 #endif
 
